@@ -6,8 +6,9 @@ from quickbuild.exceptions import (
     QBNotFoundError,
     QBProcessingError,
 )
+from quickbuild.helpers import ContentType
 
-__version__ = '0.4.1'
+__version__ = '0.7.0'
 
 __all__ = (
     # adapters
@@ -18,4 +19,6 @@ __all__ = (
     'QBForbiddenError',
     'QBNotFoundError',
     'QBProcessingError',
+    # other
+    'ContentType',
 )
