@@ -1,17 +1,23 @@
+from .agents import Agents
 from .audits import Audits
 from .builds import Builds
 from .configurations import Configurations
+from .dashboards import Dashboards
 from .groups import Groups
+from .memberships import Memberships
 from .requests import Requests
 from .system import System
 from .tokens import Tokens
 from .users import Users
 
 __all__ = (
+    'Agents',
     'Audits',
     'Builds',
     'Configurations',
+    'Dashboards',
     'Groups',
+    'Memberships',
     'Requests',
     'System',
     'Tokens',
