@@ -1,6 +1,7 @@
+from functools import partial
 from typing import List, Optional, Union
 
-from quickbuild.helpers import response2py
+from quickbuild.helpers import ContentType, response2py
 
 
 class Users:
@@ -24,28 +25,27 @@ class Users:
     def get_info(self,
                  user_id: int,
                  *,
-                 as_xml: Optional[bool] = False
+                 content_type: Optional[ContentType] = None
                  ) -> Union[dict, str]:
         """
         Get information about specified user.
 
         Args:
-            user_id (int): user identifier.
-            as_xml (Optional[bool]) return XML document instead of json.
+            user_id (int):
+                User identifier.
+
+            content_type (Optional[ContentType]):
+                Select needed content type if not set, default value of client
+                instance is used.
 
         Returns:
             dict: information about user.
         """
-        def callback(response: str) -> Union[dict, str]:
-            if as_xml:
-                return response
-
-            return response2py(response)
-
         return self.quickbuild._request(
             'GET',
             'users/{}'.format(user_id),
-            callback=callback
+            callback=partial(response2py, content_type=content_type),
+            content_type=content_type,
         )
 
     def get_display_name(self, user_id: int) -> str:
@@ -86,20 +86,22 @@ class Users:
 
     def create(self, configuration: str) -> int:
         """
-        Create a new user using XML configuration.
+        Create a new user using XML/JSON configuration.
 
-        Please note that the posted XML should NOT contain the id element;
-        otherwise, QuickBuild will treat the post as an update to the user with
-        that id. Normally you do not need to create the XML from scratch: you may
+        Normally you do not need to create the XML from scratch: you may
         retrieve XML representation of a templating user using ``get_info()``,
-        remove the id element, modify certain parts and post back to above url.
+        remove the id element, modify certain parts and use it.
 
         Args:
-            configuration (str): XML document.
+            configuration (str): XML/JSON document.
 
         Returns:
             int: id of the newly created user.
+
+        Raises:
+            QBError: configuration validation error.
         """
+        self.quickbuild._validate_for_id(configuration)
         return self.update(configuration)
 
     def delete(self, user_id: int) -> None:
@@ -115,4 +117,5 @@ class Users:
         return self.quickbuild._request(
             'DELETE',
             'users/{}'.format(user_id),
+            callback=response2py,
         )
