@@ -24,3 +24,10 @@ class QBNotFoundError(QBError):
     Raises when request return HTTP code 404 (not found)
     """
     ...
+
+
+class QBServerError(QBError):
+    """
+    Raises when request return HTTP code 500 (server error)
+    """
+    ...
