@@ -5,7 +5,13 @@ from http import HTTPStatus
 import pytest
 import responses
 
-from quickbuild import AsyncQBClient, QBNotFoundError, QBProcessingError
+from quickbuild import (
+    AsyncQBClient,
+    QBError,
+    QBNotFoundError,
+    QBProcessingError,
+)
+from quickbuild.helpers import ContentType
 
 BUILD_INFO_XML = r"""<?xml version="1.0" encoding="UTF-8"?>
 
@@ -188,7 +194,7 @@ def test_get_info(client):
     response = client.builds.get_info(1)
     assert response['id'] == 1
 
-    response = client.builds.get_info(1, as_xml=True)
+    response = client.builds.get_info(1, content_type=ContentType.XML)
     assert isinstance(response, str)
 
 
@@ -439,7 +445,13 @@ def test_create(client):
         body='5',
     )
 
-    response = client.builds.create(BUILD_INFO_XML)
+    xml_with_id = BUILD_INFO_XML
+    xml_without_id = xml_with_id.replace('<id>1</id>', '')
+
+    with pytest.raises(QBError):
+        client.builds.create(xml_with_id)
+
+    response = client.builds.create(xml_without_id)
     assert response == 5
 
 
@@ -451,7 +463,7 @@ def test_delete(client):
         content_type='text/plain',
     )
 
-    assert client.builds.delete(5) == ''
+    assert client.builds.delete(5) is None
 
 
 @pytest.mark.asyncio
@@ -465,6 +477,6 @@ async def test_delete_async(aiohttp_mock):
         )
 
         response = await client.builds.delete(5)
-        assert response == ''
+        assert response is None
     finally:
         await client.close()
